#!/bin/bash
# $File: etc/config.inc.sh $
# $Author: Marko Schulz <info@tuxnet24.de> $
# $Date: 2018-12-21 07:55:14 +0200 (Fr, 21 Dez 2018) $
# $HeadURL: https://gitbucket.tuxnet24.de/git/tuxnet24/letsencrypt.git $
# $Description: Configuration for the letsencrypt script. $
# *******************************************************
#
# [GLOBAL SERVER CONFIGURATION]
#
# server configuration variables (bin/certificate) as assoc array
declare -A cfg

# Path to the certbot binary
cfg[certbotbin]="/usr/bin/certbot"

# Path to the post-hook script
cfg[posthook]="/usr/local/share/letsencryptcert/hook/posthook"

# Path to the pre-hook script
cfg[prehook]="/usr/local/share/letsencryptcert/hook/prehook"

# Path to the deploy path, where the certificates will be copyed
cfg[deploypath]="/var/www/letsencryptcert"

# Path to the cloudflare credentials file
cfg[credentialfile]="/etc/letsencrypt/cloudflare.ini"

# Path to the letsencrypt main directory, where the certificates will be stored
cfg[certpath]="/etc/letsencrypt"

# Path of the temporary certbothook directroy
cfg[temppath]="/tmp/certbothook"

# Days, before an certificate expire
cfg[expired]="30d"


# [GLOBAL CLIENT CONFIGURATION]
#
# client configuration variables (bin/deploy) as assoc array
declare -A client

# The hostname of this maschine
client[hostname]=$( hostname )

# Path to the certificate portal
client[href]="https://letsencrypt.example.com"

# Username for the certificate portal
client[user]="<letsencrypt_user>"

# Password for the certificate portal
client[pass]="<letsencrypt_pass>"

# Target directory for the certificates
client[goal]="/etc/ssl/letsencrypt"

# Path to the local flat file database
client[file]="${cwd}/cache/$(basename $0 .sh).dat"

# Temporary file to storage page content
client[page]="/tmp/${ppid}-letsencryptcerts-pagesource.log"

# Temporary file to store all to delete certificates
client[trash]="/tmp/${ppid}-letsencryptcerts-trash.log"

# Temporary file to store all to downloads certificates
client[logs]="/tmp/${ppid}-letsencryptcerts.log"

# Temporary backup directory
client[save]="/tmp/save"

# The notify mail address
client[recipient]="root@localhost"

# The subject of the notify message
client[subject]="[${LOGNAME}@${client[hostname]}] Letsencryptcerts Report %s"

# Send message on success (Yes|No)
client[onsuccess]="Yes"

# vim: syntax=bash ts=2 sw=2 sts=2 sr noet
# EOF
